/*
Éric Seigne - 2019 - GNU AGPLv3
*/
var MyCamera;
var pictureSource;   // picture source
var destinationType; // sets the format of returned value

// Wait for Cordova to connect with the device
//
document.addEventListener("deviceready",onDeviceReady,false);

// Cordova is ready to be used!
//
function onDeviceReady() {
  MyCamera=navigator.camera;
  pictureSource=navigator.camera.PictureSourceType;
  destinationType=navigator.camera.DestinationType;
}

// Called when a photo is successfully retrieved
//
function onPhotoDataSuccess(imageData) {
  // Uncomment to view the base64 encoded image data
  // console.log(imageData);

  // Get image handle
  //
  var smallImage = document.getElementById('smallImage');

  // Unhide image elements
  //
  smallImage.style.display = 'block';

  // Show the captured photo
  // The inline CSS rules are used to resize the image
  //
  smallImage.src = "data:image/jpeg;base64," + imageData;
}

// Called when a photo is successfully retrieved
//
function onPhotoURISuccess(imageURI) {
  // Uncomment to view the image file URI
  // console.log(imageURI);

  // Get image handle
  //
  var largeImage = document.getElementById('largeImage');

  // Unhide image elements
  //
  largeImage.style.display = 'block';

  // Show the captured photo
  // The inline CSS rules are used to resize the image
  //
  largeImage.src = imageURI;
}

// A button will call this function
//
function capturePhoto() {
  // Take picture using device camera and retrieve image as base64-encoded string
  MyCamera.getPicture(onPhotoDataSuccess, onFail, { quality: 50, destinationType: destinationType.DATA_URL });
}

// A button will call this function
//
function capturePhotoEdit() {
  // Take picture using device camera, allow edit, and retrieve image as base64-encoded string
  MyCamera.getPicture(onPhotoDataSuccess, onFail, { quality: 10, allowEdit: true, destinationType: destinationType.DATA_URL });
}

// A button will call this function
//
function getPhoto(source) {
  // Retrieve image file location from specified source
  MyCamera.getPicture(onPhotoURISuccess, onFail, { quality: 50, destinationType: destinationType.FILE_URI, sourceType: source });
}

// Called if something bad happens.
//
function onFail(message) {
  alert('Failed because: ' + message);
}

function getImageAsBlob(url, blobCallback) {
  var xhr = new XMLHttpRequest();
  xhr.open("GET", url, true);
  xhr.responseType = "arraybuffer";
  xhr.onload = function(ev) {
    // Obtain a blob: URL for the image data.
    var arrayBufferView = new Uint8Array(this.response);
    var blob = new Blob([ arrayBufferView ], { type: "image/jpeg" });
    blobCallback(blob);
  };
  xhr.send();
}

function showModal() {
  var $this = $( this ),
  theme = $this.jqmData( "theme" ) || $.mobile.loader.prototype.options.theme,
  msgText = $this.jqmData( "msgtext" ) || $.mobile.loader.prototype.options.text,
  textVisible = $this.jqmData( "textvisible" ) || $.mobile.loader.prototype.options.textVisible,
  textonly = !!$this.jqmData( "textonly" );
  html = $this.jqmData( "html" ) || "";
  $.mobile.loading( "show", {
    text: msgText,
    textVisible: textVisible,
    theme: theme,
    textonly: textonly,
    html: html
  });
}

function hideModal() {
  $.mobile.loading( "hide" );
}

function sendForm() {
  showModal();

  $.ajaxSetup({
    headers: {
      'X-CSRF-TOKEN': localStorage.getItem("api_token")
    }
  });

  var formdata = new FormData($("#leform")[0]);
  formdata.append('_token', localStorage.getItem("api_token"));

  var hasImage = document.getElementById('smallImage');
  if(hasImage != null) {
    var file = document.getElementById('smallImage').getAttribute("src");
    formdata.append("afile", file);
  }

  //On sauvegarde la date pour la proposer par défaut au prochain scan
  if(document.getElementById('ladate')) {
    // console.log("on a ladate : " + document.getElementById('ladate').value);

    localStorage.setItem("ladate",document.getElementById('ladate').value);
  }

  // var leform = document.getElementById("leform");
  // for( var i=0; i<leform.elements.length; i++ )
  // {
  //   var fieldName  = leform.elements[i].name;
  //   var fieldValue = leform.elements[i].value;
  //   fd.append(fieldName, fieldValue);
  // }


  //'multipart/form-data'
  $.ajax({
    url: localStorage.getItem("api_server") + "/api/ldfs",
    method: "POST",
    data: formdata,
    processData: false,
    contentType: false,
    beforeSend: function (xhr) {
      xhr.setRequestHeader('Authorization', 'Bearer ' + localStorage.getItem("api_token"));
    },
    success: function(result) {
      hideModal();
      console.log('upload done');
      window.location.assign('uploadDone.html');
    },
    error: function(result) {
      hideModal();
      console.log('upload error');
    }
  });
}
